@@ -15,8 +15,11 @@
 
 G_BEGIN_DECLS
 
-void     gdu_format_volume_dialog_show (GduWindow    *window,
-                                        UDisksObject *object);
+void     gdu_format_volume_dialog_show         (GduWindow    *window,
+                                                UDisksObject *object);
+void     gdu_format_volume_dialog_show_for_xid (UDisksClient *client,
+                                                gint          xid,
+                                                UDisksObject *object);
 
 G_END_DECLS
 
